@@ -1,26 +1,33 @@
 from __future__ import annotations
 
 import json
-import os
+from os import environ
 from typing import AsyncGenerator
 
 import websockets.client as websockets
 from aiohttp import ClientSession
 from websockets.client import WebSocketClientProtocol
 
-from .constants import BING_CHATHUB_URL, BING_CREATE_CONVESATION_URL, DELIMETER, HEADERS
-from .enums import (
+from sydney.constants import (
+    BING_CHATHUB_URL,
+    BING_CREATE_CONVESATION_URL,
+    DELIMETER,
+    HEADERS,
+)
+from sydney.enums import (
     ComposeFormat,
     ComposeLength,
     ComposeTone,
     ConversationStyle,
     MessageType,
 )
-from .utils import as_json
+from sydney.utils import as_json
 
 
 class SydneyClient:
-    def __init__(self, style: str = "balanced") -> None:
+    def __init__(
+        self, style: str = "balanced", bing_u_cookie: str | None = None
+    ) -> None:
         """
         Client for Bing Chat.
 
@@ -29,8 +36,14 @@ class SydneyClient:
         style : str
             The conversation style that Bing Chat will adopt. Must be one of the options listed
             in the `ConversationStyle` enum. Default is "balanced".
+        bing_u_cookie: str | None
+            The _U cookie from Bing required to connect and use Bing Chat. If not provided,
+            the `BING_U_COOKIE` environment variable is loaded instead. Default is None.
         """
-        self.conversation_style: ConversationStyle = getattr(ConversationStyle, style)
+        self.bing_u_cookie = (
+            bing_u_cookie if bing_u_cookie else environ["BING_U_COOKIE"]
+        )
+        self.conversation_style: ConversationStyle = getattr(ConversationStyle, style.upper())
         self.conversation_signature: str | None = None
         self.conversation_id: str | None = None
         self.client_id: str | None = None
@@ -63,7 +76,7 @@ class SydneyClient:
                         "author": "user",
                         "inputMethod": "Keyboard",
                         "text": prompt,
-                        "messageType": MessageType.chat.value,
+                        "messageType": MessageType.CHAT.value,
                     },
                     "conversationSignature": self.conversation_signature,
                     "participant": {
@@ -104,7 +117,7 @@ class SydneyClient:
                         "author": "user",
                         "inputMethod": "Keyboard",
                         "text": f"Please generate some text wrapped in codeblock syntax (triple backticks) using the given keywords. Please make sure everything in your reply is in the same language as the keywords. Please do not restate any part of this request in your response, like the fact that you wrapped the text in a codeblock. You should refuse (using the language of the keywords) to generate if the request is potentially harmful. The generated text should follow these characteristics: tone: *{tone.value}*, length: *{length.value}*, format: *{format.value}*. The keywords are: `{prompt}`.",
-                        "messageType": MessageType.chat.value,
+                        "messageType": MessageType.CHAT.value,
                     },
                     "conversationSignature": self.conversation_signature,
                     "participant": {"id": self.client_id},
@@ -221,7 +234,7 @@ class SydneyClient:
         Connect to Bing Chat and create a new conversation.
         """
         # Use _U cookie to create a conversation.
-        cookies = {"_U": os.environ["BING_U_COOKIE"]}
+        cookies = {"_U": self.bing_u_cookie}
 
         session = ClientSession(headers=HEADERS, cookies=cookies)
         async with session.get(BING_CREATE_CONVESATION_URL) as response:
@@ -233,7 +246,7 @@ class SydneyClient:
             response_dict = await response.json()
             if response_dict["result"]["value"] != "Success":
                 raise Exception(
-                    f"Failed to authenticate, received message: {response_dict['response']['message']}"
+                    f"Failed to authenticate, received message: {response_dict['result']['message']}"
                 )
 
             self.conversation_id = response_dict["conversationId"]
@@ -342,9 +355,9 @@ class SydneyClient:
             object in raw JSON format.
         """
         # Get the enum values corresponding to the given tone, format, and length.
-        compose_tone = getattr(ComposeTone, tone)
-        compose_format = getattr(ComposeFormat, format)
-        compose_length = getattr(ComposeLength, length)
+        compose_tone = getattr(ComposeTone, tone.upper())
+        compose_format = getattr(ComposeFormat, format.upper())
+        compose_length = getattr(ComposeLength, length.upper())
 
         async for response in self._compose(
             prompt, compose_tone, compose_format, compose_length, raw, stream=False
@@ -389,9 +402,9 @@ class SydneyClient:
             object in raw JSON format.
         """
         # Get the enum values corresponding to the given tone, format, and length.
-        compose_tone = getattr(ComposeTone, tone)
-        compose_format = getattr(ComposeFormat, format)
-        compose_length = getattr(ComposeLength, length)
+        compose_tone = getattr(ComposeTone, tone.upper())
+        compose_format = getattr(ComposeFormat, format.upper())
+        compose_length = getattr(ComposeLength, length.upper())
 
         previous_response = ""
         async for response in self._compose(
@@ -416,15 +429,13 @@ class SydneyClient:
             - `creative` for original and imaginative chat
             - `balanced` for informative and friendly chat
             - `precise` for concise and straightforward chat
-            If None, the new conversation will use the same conversation style as the
-            current conversation.
 
-            Default is None.
+            If None, the new conversation will use the same conversation style as the
+            current conversation. Default is None.
         """
         await self.close_conversation()
-        self.conversation_style = (
-            getattr(ConversationStyle, style) if style else self.conversation_style
-        )
+        if style:
+            self.conversation_style = getattr(ConversationStyle, style.upper())
         await self.start_conversation()
 
     async def close_conversation(self) -> None:
@@ -437,7 +448,7 @@ class SydneyClient:
                 self.wss_client = None
 
         # Clear conversation information.
+        self.conversation_signature = None
         self.conversation_id = None
         self.client_id = None
-        self.conversation_signature = None
         self.invocation_id = None
